@@ -70,11 +70,13 @@ render_base_manuals <- function(outdir = '.'){
 #' @export
 #' @rdname html_manual
 r_universe_link <- function(package){
-  pkgurl <- tryCatch(find_package_url_internal(package), error = message)
-  if(length(pkgurl)){
-    value <- sprintf('%s/%s.html', pkgurl, package)
-    message(sprintf("Using link for package '%s' -> %s", package, value))
-    value
+  if(package %in% basepkgs){
+    return(sprintf('https://r-universe.dev/manuals/%s.html', package))
+  }
+  link <- tryCatch(lookup_docs_link(package), error = message)
+  if(length(link)){
+    message(sprintf("Using link for package '%s' -> %s", package, link))
+    link
   } else {
     message(sprintf("Did not find suitable link for package '%s'", package))
   }
@@ -274,16 +276,21 @@ write_footer <- function(doc){
   xml2::xml_set_text(p, sprintf('Rendered with postdoc %s', utils::packageVersion('postdoc')))
 }
 
-find_package_url_internal <- function(package){
-  url <- sprintf('https://r-universe.dev/stats/powersearch?limit=50&all=true&q=package:%s', package)
-  out <- jsonlite::fromJSON(url)
+lookup_docs_link <- function(package){
+  res <- curl::curl_fetch_memory(sprintf('https://api.cran.dev/%s', package))
+  if(res$status_code == 200){
+    out <- jsonlite::fromJSON(rawToChar(res$content))
+    if(length(out$devel$docs)){
+      return(out$devel$docs)
+    }
+    if(length(out$release$docs)){
+      return(out$release$docs)
+    }
+    stop('Unexpected response from cran.dev for: ', package)
+  }
   my_universe <- Sys.getenv("MY_UNIVERSE")
-  link <- if(length(out$results)){
-    sprintf("https://%s.r-universe.dev/manual", out$results[['_user']][1])
-  } else if(package %in% universe_list(my_universe)){
-    sprintf('%s/%s', my_universe, package)
-  } else if(package %in% basepkgs){
-    'https://r-universe.dev/manuals'
+  if(package %in% universe_list(my_universe)){
+    sprintf("%s/%s/doc/manual.html", my_universe, package)
   }
 }
 
@@ -291,7 +298,7 @@ list_universe_packages_internal <- function(universe){
   if(length(universe) && nchar(universe)){
     message("Quering packages in: ", universe)
     if(nchar(universe)){
-      jsonlite::fromJSON(sprintf('%s/packages', universe))
+      jsonlite::fromJSON(sprintf('%s/api/ls', universe))
     }
   }
 }
